.. include:: ../../README.rst



Index
-----


.. toctree::
    :maxdepth: 1
    :caption: Guides

    intro-guide.ipynb
    ml-pipeline.ipynb

.. toctree::
    :maxdepth: 1
    :caption: Main Concepts

    hashing-and-mutation.ipynb
    API.rst

.. toctree::
    :maxdepth: 1
    :caption: Project Information

    contributing.rst
    history.rst
